==> OpenCL-0.8.0.tgz: OpenCL-0.8.0/include/pubkey.h <==
/*************************************************
* Public Key Interface Header File               *
* (C) 1999-2002 The OpenCL Project               *
*************************************************/

#ifndef OPENCL_PUBKEY_H__
#define OPENCL_PUBKEY_H__

#include <opencl/pk_base.h>

namespace OpenCL {

/*************************************************
* IF_Scheme_Encryptor                            *
*************************************************/
template<typename PK, typename PAD>
class IF_Scheme_Encryptor : public PK_Encryptor
   {
   public:
      SecureVector<byte> encrypt(const byte[], u32bit) const;
      IF_Scheme_Encryptor(PK& k) : key(k) {}
   private:
      PAD padder;
      const PK& key;
   };

/*************************************************
* IF_Scheme_Decryptor                            *
*************************************************/
template<typename PK, typename PAD>
class IF_Scheme_Decryptor : public PK_Decryptor
   {
   public:
      SecureVector<byte> decrypt(const byte[], u32bit) const;
      IF_Scheme_Decryptor(PK& k) : key(k) {}
   private:
      PAD padder;
      const PK& key;
   };

/*************************************************
* IF_Scheme_Verifier                             *
*************************************************/
template<typename PK, typename H, typename PAD>
class IF_Scheme_Verifier : public PK_Verifier
   {
   public:
      void update(const byte in[], u32bit length) { hash.update(in, length); }
      bool valid_signature(const byte[], u32bit);
      IF_Scheme_Verifier(PK& k) : key(k) {}
   private:
      H hash;
      PAD padder;
      const PK& key;
   };

/*************************************************
* IF_Scheme_Singer                               *
*************************************************/
template<typename PK, typename H, typename PAD>
class IF_Scheme_Signer : public PK_Signer
   {
   public:
      void update(const byte in[], u32bit length) { hash.update(in, length); }
      SecureVector<byte> signature();
      IF_Scheme_Signer(PK& k) : key(k) {}
   private:
      H hash;
      PAD padder;
      const PK& key;
   };

}

#endif

#ifndef OPENCL_PUBKEY_ICC__
#define OPENCL_PUBKEY_ICC__
#include <opencl/pubkey.icc>
#endif

==> OpenCL-0.8.1.tgz: OpenCL-0.8.1/include/pubkey.h <==
/*************************************************
* Public Key Interface Header File               *
* (C) 1999-2002 The OpenCL Project               *
*************************************************/

#ifndef OPENCL_PUBKEY_H__
#define OPENCL_PUBKEY_H__

#include <opencl/pk_base.h>
#include <opencl/pk_misc.h>

namespace OpenCL {

/*************************************************
* IF_Scheme_Encryptor                            *
*************************************************/
template<typename PK, typename PAD>
class IF_Scheme_Encryptor : public PK_Encryptor
   {
   public:
      SecureVector<byte> encrypt(const byte[], u32bit) const;
      IF_Scheme_Encryptor(PK& k) : key(k) { padder = new PAD; }
   private:
      MessageEncodingMethod* padder;
      const PK& key;
   };

/*************************************************
* IF_Scheme_Decryptor                            *
*************************************************/
template<typename PK, typename PAD>
class IF_Scheme_Decryptor : public PK_Decryptor
   {
   public:
      SecureVector<byte> decrypt(const byte[], u32bit) const;
      IF_Scheme_Decryptor(PK& k) : key(k) { padder = new PAD; }
   private:
      MessageEncodingMethod* padder;
      const PK& key;
   };

/*************************************************
* IF_Scheme_Verifier                             *
*************************************************/
template<typename PK, typename H, typename PAD>
class IF_Scheme_Verifier : public PK_Verifier
   {
   public:
      void update(const byte in[], u32bit length) { hash->update(in, length); }
      bool valid_signature(const byte[], u32bit);
      IF_Scheme_Verifier(PK& k) : key(k) { padder = new PAD; hash = new H; }
   private:
      HashFunction* hash;
      MessageEncodingMethod* padder;
      const PK& key;
   };

/*************************************************
* IF_Scheme_Singer                               *
*************************************************/
template<typename PK, typename H, typename PAD>
class IF_Scheme_Signer : public PK_Signer
   {
   public:
      void update(const byte in[], u32bit length) { hash->update(in, length); }
      SecureVector<byte> signature();
      IF_Scheme_Signer(PK& k) : key(k) { padder = new PAD; hash = new H; }
   private:
      HashFunction* hash;
      MessageEncodingMethod* padder;
      const PK& key;
   };

}

#endif

#ifndef OPENCL_PUBKEY_ICC__
#define OPENCL_PUBKEY_ICC__
#include <opencl/pubkey.icc>
#endif
